# -*- coding: utf-8 -*-

"""Top-level package for PrettyQt."""

from . import core, gui, syntaxhighlighters, widgets

__author__ = """Philipp Temminghoff"""
__email__ = "phil65@kodi.tv"
__version__ = "0.17.0"

__all__ = ["core", "widgets", "gui", "syntaxhighlighters"]
